@@ -9,15 +9,20 @@ class quiver:
         'X-CSRFToken': 'TyTJwjuEC7VV7mOqZ622haRaaUr0x0Ng4nrwSRFKQs7vdoBcJlK9qjAS69ghzhFu',
         'Authorization': "Token "+self.token}
     
-    def congress_trading(self, ticker="", politician=False):
+    def congress_trading(self, ticker="", politician=False, recent=True):
+        if recent:
+            urlStart = 'https://api.quiverquant.com/beta/live/congresstrading'
+        else:
+            urlStart = 'https://api.quiverquant.com/beta/bulk/congresstrading'
         if politician:
             ticker = ticker.replace(" ", "%20")
-            url = "https://api.quiverquant.com/beta/live/congresstrading?representative="+ticker
+            url = urlStart+"?representative="+ticker
             
         elif len(ticker)>0:
-            url = "https://api.quiverquant.com/beta/historical/congresstrading/"+ticker
+            url = urlStart+"/"+ticker
         else:
-            url = "https://api.quiverquant.com/beta/live/congresstrading"
+            url = urlStart
+        print(url)
         r = requests.get(url, headers=self.headers)
         j = json.loads(r.content)
         df = pd.DataFrame(j)
@@ -252,7 +257,47 @@ class quiver:
         df["Date"] = pd.to_datetime(df["Date"], unit="ms")       
         return df
     
+    def sec13FChanges(self, ticker="", date="", owner="", period=""):
+        separator = "?"
+        url = "https://api.quiverquant.com/beta/live/sec13fchanges"
+        if len(ticker)>0:
+            url = url+separator+"ticker="+ticker
+            separator = "&"
+        if len(date)>0:
+            url = url+separator+"date="+date
+            separator = "&"
+        if len(owner)>0:
+            url = url+separator+"owner="+owner
+            separator="&"
+        if len(period)>0:
+            url = url+separator+"period="+period
+            separator="&"
+            
+        print("Pulling data from: ", url)     
+        r = requests.get(url, headers=self.headers)
         
+        if r.text == '"Upgrade your subscription plan to access this dataset."':
+            raise NameError('Upgrade your subscription plan to access this dataset.')
+            
+        df = pd.DataFrame(json.loads(r.content))
+        df["ReportPeriod"] = pd.to_datetime(df["ReportPeriod"], unit='ms')
+#         #Can edit this out once we get past May 25th
+#         values = []
+#         for val in df["Value"]:
+#             if len(val)>=900:
+#                 values.append(val[:len(val)//1000])
+#             else:
+#                 values.append(val)
+#         df["Value"] = values
+        ########
+        
+#         df["Value"] = df["Value"].str.replace(",", "")
+#         df["Value"] = df["Value"].astype(float)
+        
+#         df["Shares"] = df["Shares"].str.replace(",", "")
+#         df["Shares"] = df["Shares"].astype(float)
+        df["Date"] = pd.to_datetime(df["Date"], unit="ms")       
+        return df    
     
     def wallstreetbetsComments(self, ticker="", freq="", date_from = "", date_to = ""):
         separator = "?"
